import Vue from 'vue'
import Vuex from 'vuex'

Vue.use(Vuex); //vue的插件机制

import api from '@/api/api.js'

//Vuex.Store 构造器选项
const store = new Vuex.Store({
	state: {
		configList: {}, //配置列表
		shop : false,//身份判断如果不需要，可以删除
		userInfo : {}, //用户信息
		userInfoVip : {}, //用户Vip信息
	},
	getters: {
		// 角色 true为水洗店 false为酒店 ： 身份判断如果不需要，可以删除
		userShop(state){
			return state.shop
		}
	},
	mutations: {
		// 初始化配置
		initConfig(state){
			api('getConfig', res => {
				const configList = {
					...state.configList,
				}
				if (res.code == 200) {
					res.result.forEach(n => {
						configList[n.keyName] = n.keyContent;
						configList[n.keyName + '_keyValue'] = n.keyValue;
					});
				}
				state.configList = configList
				uni.$emit('initConfig', state.configList)
			})
			
			// let config = ['getPrivacyPolicy', 'getUserAgreement']
			// config.forEach(k => {
			// 	api(k, res => {
			// 		if (res.code == 200) {
			// 			state.configList[k] = res.result
			// 		}
			// 	})
			// })
		},
		// 微信登录
		login(state){
			uni.showLoading({
				title: '登录中...'
			})
			uni.login({
				success(res) {
					if(res.errMsg != "login:ok"){
						return
					}
            
					let data = {
						code: res.code,
					}

					if (uni.getStorageSync('shareId')) {
						data.shareId = uni.getStorageSync('shareId')
					}
            
					if (uni.getStorageSync('id')) {
							data.id = uni.getStorageSync('id')
					}
			
					if (uni.getStorageSync('state')) {
						data.state = uni.getStorageSync('state')
					}
					
					api('wxLogin', data, res => {
						
						uni.hideLoading()
						
						if(res.code != 200){
							return
						}
						
						Vue.set(state, 'userInfo', res.result.userInfo)
						uni.setStorageSync('token', res.result.token)
						
						if(!state.userInfo.nickName || !state.userInfo.headImage){
							uni.navigateTo({
								url: '/pages_order/auth/wxUserInfo?mode=add'
							})
						}else{
							uni.navigateBack({
								delta: 1,
								fail: () => {
									uni.reLaunch({
										url: '/pages/index/index'
									})
								}
							});
						}
					})
				}
			})
		},
		// 获取用户个人信息
		getUserInfo(state){
			api('getInfo', res => {
				if(res.code == 200){
					Vue.set(state, 'userInfo', res.result)
				}
			})
		},
		// 获取用户个人信息
		getUserInfoVip(state){
			api('getUserInfoVip', res => {
				if(res.code == 200){
					Vue.set(state, 'userInfoVip', res.result)
				}
			})
		},
		// 退出登录
		logout(state){
			uni.showModal({
				title: '确认退出登录吗',
				success(r) {
					if(r.confirm){
						Vue.set(state, 'userInfo', {})
						state.role = false
						uni.removeStorageSync('token')
						uni.reLaunch({
							url: '/pages/index/index'
						})
					}
				}
			})
		},
	},
	actions: {},
})

export default store